Struct libp2p_plaintext::PlainText1Config [−][src]
pub struct PlainText1Config;
PlainText1Config is an insecure connection handshake for testing purposes only.
Note: Given that
PlainText1Confighas no notion of exchanging peer identity information it is not compatible with thelibp2p_core::transport::upgrade::Builderpattern. SeePlainText2Configif compatibility is needed. Even though not compatible with the Builder pattern one can still do an upgrade manually:
MemoryTransport::default() .and_then(move |io, endpoint| { libp2p_core::upgrade::apply( io, PlainText1Config{}, endpoint, libp2p_core::transport::upgrade::Version::V1, ) }) .map(|plaintext, _endpoint| { unimplemented!(); // let peer_id = somehow_derive_peer_id(); // return (peer_id, plaintext); });